%define		major		1
%define		libname		%mklibname opencolorio %{major}
%define		develname	%mklibname opencolorio -d

Name:		opencolorio
Version:	1.1.1
Release:	%mkrel 1
Summary:	A complete color management solution
Group:		System/Libraries
License:	BSD
URL:		https://opencolorio.org/
Source0:	https://github.com/AcademySoftwareFoundation/OpenColorIO/archive/v%{version}/OpenColorIO-%{version}.tar.gz
Patch1:		opencolorio-1.1.0-setuptools.patch
Patch2:		opencolorio-1.1.0-use-GNUInstallDirs-and-fix-install-location-for-cmake-files.patch
# Fix build of Python bindings with GCC 8
# https://github.com/AcademySoftwareFoundation/OpenColorIO/pull/518
Patch3:		ocio-1.1.0-gcc8.patch
# Reverts bogus forward declare of yaml-cpp symbols
# https://github.com/AcademySoftwareFoundation/OpenColorIO/issues/517
Patch4:		opencolorio-1.1.0-fix-yaml-cpp-0.6.patch

BuildRequires:	cmake
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(markupsafe)

%description
OpenColorIO (OCIO) is a complete color management solution geared towards
motion picture production with an emphasis on visual effects and computer
animation. OCIO provides a straightforward and consistent user experience
across all supporting applications while allowing for sophisticated
back-end configuration options suitable for high-end production usage.
OCIO is compatible with the Academy Color Encoding Specification (ACES)
and is LUT-format agnostic, supporting many popular formats.

%package -n %{libname}
Summary:	A complete color management solution
Group:		System/Libraries
Obsoletes:	%{_lib}OpenColorIO1 < 1.0.9-14

%description -n %{libname}
A complete color management solution.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}OpenColorIO-devel < 1.0.9-14

%description -n %{develname}
Development files for %{name} library.

%package -n python3-pyopencolorio
Summary:	Python 3 Bindings for %{name}
Group:		Development/Python

%description -n python3-pyopencolorio
This package contains python 3 bindings for %{name}.

%package -n python3-pyopencolorio-devel
Summary:	Python 3 Bindings for %{name}
Group:		Development/Python
Requires:	python3-pyopencolorio = %{version}
Requires:	pkgconfig(python3)

%description -n python3-pyopencolorio-devel
This package contains development files for python 3 bindings
for %{name}.

%prep
%autosetup -n OpenColorIO-%{version} -p1

%build
%cmake \
	-DOCIO_BUILD_STATIC=OFF \
	-DOCIO_BUILD_APPS=OFF \
	-DOCIO_BUILD_TRUELIGHT=OFF \
	-DOCIO_BUILD_NUKE=OFF \
	-DUSE_EXTERNAL_YAML=ON \
	-DUSE_EXTERNAL_TINYXML=ON \
	-DUSE_EXTERNAL_LCMS=ON \
	-DUSE_EXTERNAL_SETUPTOOLS=ON \
	-DPYTHON=%{__python3} \
%ifnarch x86_64
	-DOCIO_USE_SSE=OFF \
%endif
	-DOCIO_BUILD_PYGLUE=ON
%cmake_build

%install
%cmake_install

%files
%doc ChangeLog README.md
%license LICENSE
%{_datadir}/ocio/

%files -n %{libname}
%{_libdir}/libOpenColorIO.so.%{major}
%{_libdir}/libOpenColorIO.so.%{major}.*

%files -n %{develname}
%{_libdir}/libOpenColorIO.so
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/cmake/OpenColorIO/
%{_includedir}/OpenColorIO/

%files -n python3-pyopencolorio
%{python3_sitearch}/PyOpenColorIO.so

%files -n python3-pyopencolorio-devel
%{_includedir}/PyOpenColorIO/


%changelog
* Fri Oct 30 2020 daviddavid <daviddavid> 1.1.1-1.mga8
+ Revision: 1640583
- new version: 1.1.1 (mga#27490)

* Mon Feb 17 2020 umeabot <umeabot> 1.1.0-7.mga8
+ Revision: 1537507
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Oct 31 2019 daviddavid <daviddavid> 1.1.0-6.mga8
+ Revision: 1457154
- rebuild for new yaml-cpp 0.6.3

* Tue Sep 17 2019 daviddavid <daviddavid> 1.1.0-5.mga8
+ Revision: 1442775
- rebuild for python3.8

* Tue Jan 08 2019 tv <tv> 1.1.0-4.mga7
+ Revision: 1352210
- rebuild with python 3.7

* Mon Nov 19 2018 akien <akien> 1.1.0-3.mga7
+ Revision: 1331922
- Rebuild for yaml-cpp 0.6.2

* Sat Sep 29 2018 daviddavid <daviddavid> 1.1.0-2.mga7
+ Revision: 1310911
- add patch to fix build with gcc8
- port the python bindings to python3
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sat May 12 2018 daviddavid <daviddavid> 1.1.0-1.mga7
+ Revision: 1228461
- new version: 1.1.0
- use a named-versioned git tarball
- enable python 2 bindings
- remove merged upstream patches

* Wed Dec 28 2016 wally <wally> 1.0.9-14.mga6
+ Revision: 1078413
- fix pkg names (use lower case)

* Wed Jan 13 2016 pterjan <pterjan> 1.0.9-13.mga6
+ Revision: 922891
- Only use sse2 on x86_64

* Fri Dec 25 2015 daviddavid <daviddavid> 1.0.9-12.mga6
+ Revision: 914616
- rebuild for new boost 1.60.0

* Wed Aug 26 2015 fwang <fwang> 1.0.9-11.mga6
+ Revision: 869487
- update file list
- do not generate cicular deps

* Mon Aug 24 2015 daviddavid <daviddavid> 1.0.9-10.mga6
+ Revision: 868897
- rebuild for new glew 1.13.0

* Tue Jun 23 2015 fwang <fwang> 1.0.9-9.mga6
+ Revision: 840520
- rebuild for new glew

* Wed Oct 15 2014 umeabot <umeabot> 1.0.9-8.mga5
+ Revision: 745822
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.9-7.mga5
+ Revision: 683197
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 akien <akien> 1.0.9-6.mga5
+ Revision: 673528
- Add upstream patch to fix mga#13767

* Mon Sep 01 2014 luigiwalser <luigiwalser> 1.0.9-5.mga5
+ Revision: 670511
- rebuild for glew

* Tue Aug 26 2014 luigiwalser <luigiwalser> 1.0.9-4.mga5
+ Revision: 668356
- rebuild

* Mon Jul 14 2014 akien <akien> 1.0.9-3.mga5
+ Revision: 651806
- Add upstream patch for yaml-cpp 0.5.1 support

* Mon Oct 21 2013 umeabot <umeabot> 1.0.9-2.mga4
+ Revision: 538692
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 fwang <fwang> 1.0.9-1.mga4
+ Revision: 490215
- new version 1.0.9

* Wed Jul 24 2013 sander85 <sander85> 1.0.8-4.mga4
+ Revision: 457720
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 1.0.8-3.mga4
+ Revision: 454652
- rebuild for new openimageio

* Mon Jul 08 2013 fwang <fwang> 1.0.8-2.mga4
+ Revision: 451262
- rebuild for new boost

* Fri Jun 14 2013 fwang <fwang> 1.0.8-1.mga4
+ Revision: 442966
- new version 1.0.8

* Sun Jan 13 2013 umeabot <umeabot> 1.0.7-2.mga3
+ Revision: 361933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 15 2012 fwang <fwang> 1.0.7-1.mga3
+ Revision: 306636
- update file list
- update br
- imported package opencolorio

